@@ -175,7 +175,8 @@ modes only."
   "*String displayed on the modeline when flyspell is active.
 Set this to nil if you don't want a modeline indicator."
   :group 'flyspell
-  :type 'string)
+  :type '(choice string
+		 (const :tag "none" nil)))
 
 ;*---------------------------------------------------------------------*/
 ;*    Mode specific options                                            */
